pub struct Digest { /* private fields */ }Expand description
A content-addressable digest in the format algorithm:hex.
Currently only SHA256 is supported as per OCI specification.
Implementations
Sourceimpl Digest
impl Digest
Sourcepub fn new(algorithm: Algorithm, hex: impl Into<String>) -> Result<Self, Error>
pub fn new(algorithm: Algorithm, hex: impl Into<String>) -> Result<Self, Error>
Creates a new digest from algorithm and hex string.
The hex string is normalized to lowercase per OCI specification.